pub struct MetalBuffer { /* private fields */ }Expand description
A Metal buffer for vertex/uniform data
Implementations
Sourceimpl MetalBuffer
impl MetalBuffer
Sourcepub fn did_modify_range(&self, range: Range<usize>)
pub fn did_modify_range(&self, range: Range<usize>)
Notify that a range of the buffer was modified (for managed storage mode)
The call is skipped when the range cannot be expressed as the Swift
bridge’s signed Int pair — Swift reconstructs start ..< end and
traps on an overflowing or reversed range.